# -*- coding: utf-8 -*-

# mapWOC
#
# Description: Test Result Analysis.
#
# Authors:
# Felix Wolfsteller <felix.wolfsteller@intevation.de>
#
# Copyright:
# Copyright (C) 2011 Bundesamt für Sicherheit in der Informationstechnik
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2,
# or, at your option, any later version as published by the Free
# Software Foundation
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.

import json
import unittest
import os
import shutil
import datetime
import time
import tarfile
import gzip
import ConfigParser
import Queue

from sqlalchemy import *

from mapwoc.lib.hc import HC
from mapwoc.lib.hccontrol import HCControl
from mapwoc.lib.message import Message
from mapwoc.lib.redirectorvisit import RedirectorVisit
from mapwoc.lib.scanconfiguration import ScanConfiguration, VisitorBundle, VisitorConfiguration
from mapwoc.lib.trivialresponse import TrivialResponse
from mapwoc.lib.url import URL, create_URL_List
from mapwoc.lib.model.result import *
from mapwoc.nodectrl.analyserprocess import AnalysisProcess
from mapwocgui.model.meta import Session
from mapwoc.lib.mapwocqueue import Mapwocqueue
from mapwoc.masterctrl.resultanalyser import TarballAnalyser
from mapwoc.masterctrl.resultfileanalyser import ResultFileAnalyser
from mapwoc.masterctrl.twisted_master import setup_logging as master_enable_logging
from mapwoc.nodectrl.twisted_node import setup_logging as node_enable_logging


AVAILABLE_URLS = ["http://", "http://x.com"]

class TestXMLResultFileParser(unittest.TestCase):

    def setUp(self):
        self.urllist, _invalids = create_URL_List("testurls",
                                        "\n".join(AVAILABLE_URLS))
        self.scanconfiguration = ScanConfiguration("testscan")
        self.scanconfiguration.urlcollection.append(self.urllist)
        self.scanconfiguration.comment = "Test Comment"
        self.scanconfiguration.description = "Test Description"
        self.scanconfiguration.visitor_configuration = VisitorConfiguration()
        self.scanrun = ScanRun(self.scanconfiguration, "Test")
        self.scanrun.stoptime = datetime.datetime.now()
        if not os.path.isdir("tests/tmp"):
            os.mkdir("tests/tmp")
        self.dbpath = "tests/tmp/tmpdb.db"
        shutil.copyfile("tests/dbs/database.db", self.dbpath)
        engine = create_engine('sqlite:///tests/tmp/tmpdb.db')
        __c = engine.connect()
        Session.configure(bind=engine)
        Session.add(self.urllist)
        for url in self.urllist.urls:
            Session.add(url)
        Session.add(self.scanconfiguration.visitor_configuration)
        Session.add(self.scanconfiguration)
        Session.add(self.scanrun)
        Session.flush()
        Session.commit()

    def tearDown(self):
        Session.remove() # Necessary to "clear the cache"
        os.remove("tests/tmp/tmpdb.db")

    def test_parse(self):
        resultfile = "tests/resultxml/1.xml"
        r = ResultFileAnalyser(resultfile, "nonode")
        r.analyse_dry()
        self.assertTrue(r.visit)
        self.assertEquals(len(r.visit.results), 7)

